@@ -53,12 +53,8 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 1, 0, "b_client_offline_textmessage_send", 0, 1, 1 ),
  ( 0, 1, 0, "i_client_poke_power", -1, 1, 1 ),
  ( 0, 2, 0, "b_channel_create_child", 1, 0, 0 ),
- ( 0, 2, 0, "b_channel_create_modify_with_codec_celtmono48", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_modify_with_codec_opusmusic", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_modify_with_codec_opusvoice", 1, 0, 0 ),
- ( 0, 2, 0, "b_channel_create_modify_with_codec_speex16", 1, 0, 0 ),
- ( 0, 2, 0, "b_channel_create_modify_with_codec_speex32", 1, 0, 0 ),
- ( 0, 2, 0, "b_channel_create_modify_with_codec_speex8", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_permanent", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_semi_permanent", 1, 0, 0 ),
  ( 0, 2, 0, "b_channel_create_temporary", 1, 0, 0 ),
@@ -114,7 +110,6 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 2, 0, "b_client_ignore_bans", 1, 0, 0 ),
  ( 0, 2, 0, "b_client_ignore_sticky", 1, 0, 0 ),
  ( 0, 2, 0, "b_client_info_view", 1, 0, 0 ),
- ( 0, 2, 0, "b_client_issue_client_query_command", 1, 0, 0 ),
  ( 0, 2, 0, "b_client_modify_dbproperties", 1, 0, 0 ),
  ( 0, 2, 0, "b_client_modify_description", 1, 0, 0 ),
  ( 0, 2, 0, "b_client_modify_own_description", 1, 0, 0 ),
@@ -274,14 +269,10 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 2, 0, "i_icon_id", 500, 0, 0 ),
  ( 0, 2, 0, "i_max_icon_filesize", 8192, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_child", 100, 0, 0 ),
- ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_codec_celtmono48", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_codec_latency_factor_min", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_codec_maxquality", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_codec_opusmusic", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_codec_opusvoice", 100, 0, 0 ),
- ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_codec_speex16", 100, 0, 0 ),
- ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_codec_speex32", 100, 0, 0 ),
- ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_codec_speex8", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_force_password", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_modify_with_temp_delete_delay", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_channel_create_permanent", 100, 0, 0 ),
@@ -361,7 +352,6 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 2, 0, "i_needed_modify_power_client_info_view", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_client_is_priority_speaker", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_client_is_sticky", 100, 0, 0 ),
- ( 0, 2, 0, "i_needed_modify_power_client_issue_client_query_command", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_client_kick_from_channel_power", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_client_kick_from_server_power", 100, 0, 0 ),
  ( 0, 2, 0, "i_needed_modify_power_client_max_avatar_filesize", 100, 0, 0 ),
@@ -525,12 +515,8 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 2, 0, "i_needed_modify_power_virtualserver_token_use", 100, 0, 0 ),
  ( 0, 2, 0, "i_permission_modify_power", 100, 0, 0 ),
  ( 0, 3, 0, "b_channel_create_child", 1, 0, 0 ),
- ( 0, 3, 0, "b_channel_create_modify_with_codec_celtmono48", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_create_modify_with_codec_opusmusic", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_create_modify_with_codec_opusvoice", 1, 0, 0 ),
- ( 0, 3, 0, "b_channel_create_modify_with_codec_speex16", 1, 0, 0 ),
- ( 0, 3, 0, "b_channel_create_modify_with_codec_speex32", 1, 0, 0 ),
- ( 0, 3, 0, "b_channel_create_modify_with_codec_speex8", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_create_permanent", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_create_semi_permanent", 1, 0, 0 ),
  ( 0, 3, 0, "b_channel_create_temporary", 1, 0, 0 ),
@@ -588,7 +574,6 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 3, 0, "b_client_ignore_bans", 1, 0, 0 ),
  ( 0, 3, 0, "b_client_ignore_sticky", 1, 0, 0 ),
  ( 0, 3, 0, "b_client_info_view", 1, 0, 0 ),
- ( 0, 3, 0, "b_client_issue_client_query_command", 1, 0, 0 ),
  ( 0, 3, 0, "b_client_modify_dbproperties", 1, 0, 0 ),
  ( 0, 3, 0, "b_client_modify_description", 1, 0, 0 ),
  ( 0, 3, 0, "b_client_modify_own_description", 1, 0, 0 ),
@@ -720,14 +705,10 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 3, 0, "i_icon_id", 300, 0, 0 ),
  ( 0, 3, 0, "i_max_icon_filesize", 8192, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_child", 75, 0, 0 ),
- ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_codec_celtmono48", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_codec_latency_factor_min", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_codec_maxquality", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_codec_opusmusic", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_codec_opusvoice", 75, 0, 0 ),
- ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_codec_speex16", 75, 0, 0 ),
- ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_codec_speex32", 75, 0, 0 ),
- ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_codec_speex8", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_force_password", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_modify_with_temp_delete_delay", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_channel_create_permanent", 75, 0, 0 ),
@@ -807,7 +788,6 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 3, 0, "i_needed_modify_power_client_info_view", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_client_is_priority_speaker", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_client_is_sticky", 75, 0, 0 ),
- ( 0, 3, 0, "i_needed_modify_power_client_issue_client_query_command", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_client_kick_from_channel_power", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_client_kick_from_server_power", 75, 0, 0 ),
  ( 0, 3, 0, "i_needed_modify_power_client_max_avatar_filesize", 75, 0, 0 ),
@@ -943,9 +923,6 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 3, 0, "i_permission_modify_power", 75, 0, 0 ),
  ( 0, 4, 0, "b_channel_create_child", 1, 0, 0 ),
  ( 0, 4, 0, "b_channel_create_modify_with_codec_opusvoice", 1, 0, 0 ),
- ( 0, 4, 0, "b_channel_create_modify_with_codec_speex16", 1, 0, 0 ),
- ( 0, 4, 0, "b_channel_create_modify_with_codec_speex32", 1, 0, 0 ),
- ( 0, 4, 0, "b_channel_create_modify_with_codec_speex8", 1, 0, 0 ),
  ( 0, 4, 0, "b_channel_create_semi_permanent", 1, 0, 0 ),
  ( 0, 4, 0, "b_channel_create_temporary", 1, 0, 0 ),
  ( 0, 4, 0, "b_channel_create_with_description", 1, 0, 0 ),
@@ -1006,8 +983,6 @@ insert into perm_server_group (server_id, id1, id2, perm_id, perm_value, perm_ne
  ( 0, 4, 0, "i_group_needed_member_remove_power", 60, 0, 0 ),
  ( 0, 4, 0, "i_group_needed_modify_power", 75, 0, 0 ),
  ( 0, 5, 0, "b_channel_create_modify_with_codec_opusvoice", 1, 0, 0 ),
- ( 0, 5, 0, "b_channel_create_modify_with_codec_speex16", 1, 0, 0 ),
- ( 0, 5, 0, "b_channel_create_modify_with_codec_speex8", 1, 0, 0 ),
  ( 0, 5, 0, "b_channel_create_temporary", 1, 0, 0 ),
  ( 0, 5, 0, "b_channel_create_with_maxclients", 1, 0, 0 ),
  ( 0, 5, 0, "b_channel_create_with_needed_talk_power", 1, 0, 0 ),
